dump - Jumeaux
Author: tadashi-aikawa
Description: Check difference between two responses of API.

コンテンツにスキップ

# dump

APIレスポンスを保存前に加工します。

##
json

レスポンスがJSONの場合にJSON形式でフォーマットします。

- インデント(4)
- 改行

プロパティの順番について

プロパティの順番はソートされます。

### Config

#### Definitions

Key | Type | Description | Example | Default
--- | --- | --- | --- | ---
default_encoding | (string) | レスポンスヘッダにエンコーディング情報が無い場合の出力エンコーディング | euc-jp | utf8
force | (bool) | typeがjson以外の場合も強制的に変換するか | true | false

#### Examples

##### JSON形式でフォーマットする

      dump:
        - name: json

##### JSON形式でフォーマットする (エンコーディング情報が無ければEUC-JPで出力する)

      dump:
        - name: json
          config:
            default_encoding: euc-jp

##### typeに関わらずJSON形式でフォーマットする

      dump:
        - name: json
          config:
            force: True

##
xml

レスポンスがXMLの場合にXML形式でフォーマットします。

- インデント(4)
- 改行

### Config

#### Definitions

Key | Type | Description | Example | Default
--- | --- | --- | --- | ---
default_encoding | (string) | レスポンスヘッダにエンコーディング情報が無い場合の出力エンコーディング | euc-jp | utf8
force | (bool) | typeがxml以外の場合も強制的に変換するか | true | false

#### Examples

##### XML形式でフォーマットする

      dump:
        - name: xml

##### XML形式でフォーマットする (エンコーディング情報が無ければEUC-JPで出力する)

      dump:
        - name: xml
          config:
            default_encoding: euc-jp

##### typeに関わらずXML形式でフォーマットする

      dump:
        - name: xml
          config:
            force: True

##
html

レスポンスをHTML形式でフォーマットします。

- インデント(1)
- 改行

### Config

#### Definitions

Key | Type | Description | Example | Default
--- | --- | --- | --- | ---
default_encoding | (string) | レスポンスヘッダにエンコーディング情報が無い場合の出力エンコーディング | euc-jp | utf8
force | (bool) | typeがhtml以外の場合も強制的に変換するか | true | false

#### Examples

##### HTML形式でフォーマットする

      dump:
        - name: html

##### HTML形式でフォーマットする (エンコーディング情報が無ければEUC-JPで出力する)

      dump:
        - name: html
          config:
            default_encoding: euc-jp

#### typeに関わらずHTML形式でフォーマットする

      dump:
        - name: html
          config:
            force: True

##
encoding

レスポンスのエンコーディングを変換します。

### Config

#### Definitions

Key | Type | Description | Example | Default
--- | --- | --- | --- | ---
encoding | string | 変換後のエンコーディング | euc-jp |

#### Examples

##### UTF8に変換する

      dump:
        - name: encoding